import 'dart:developer';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:soliq_id/src/screens/widgets/custom_button.dart';
import 'package:soliq_id/src/screens/widgets/message_screen.dart';
import 'package:url_launcher/url_launcher_string.dart';

import '../../localizations_util.dart';
import '../data/bloc/soliq_id_bloc.dart';
import '../utils/color_utils.dart';
import '../utils/faceid_localizations.dart';
import '../utils/typography.dart';
import 'camera_screen.dart';

LocalizationType localeEnum = LocalizationType.UZ;

class FaceIdSignIn extends StatefulWidget {
  final String pinfl;
  final LocalizationType localizationType;
  final String guid;

  const FaceIdSignIn({
    Key? key,
    required this.pinfl,
    required this.localizationType,
    required this.guid,
  }) : super(key: key);

  @override
  State<FaceIdSignIn> createState() => _FaceIdSignInState();
}

class _FaceIdSignInState extends State<FaceIdSignIn> {
  String? res;
  String buttonTitle = '';
  final bool _isLoading = false;
  final DateTime date = DateTime.now();

  @override
  void initState() {
    super.initState();

    final locale = getLocalizationType(
      widget.localizationType,
    );
    localeEnum = widget.localizationType;
    log("============================== $locale(languageCode)");
    log("============================== ${widget.localizationType}");
    log("============================== ${widget.pinfl}");
    log("============================== ${widget.guid}");
    BlocProvider.of<SoliqIdBloc>(context).add(
      SoliqIdAccountInfoEvent(
        token: widget.guid,
        pinfl: int.parse(widget.pinfl),
        projectId: 0,
        lang: locale,
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    buttonTitle = getString( 'check');

    return Scaffold(
      backgroundColor: AppColor.appColor,
      appBar: AppBar(
        backgroundColor: AppColor.appColor,
        automaticallyImplyLeading: false,
        title: const Text(
          "Face ID",
          style: TextStyle(
            fontSize: 16,
            fontWeight: FontWeight.w500,
            color: Colors.black,
          ),
        ),
        actions: [
          InkWell(
            borderRadius: BorderRadius.circular(50),
            onTap: () {
              showDialog(
                  barrierDismissible: true,
                  barrierColor: const Color(0x77000000),
                  context: context,
                  builder: (_) {
                    return AlertDialog(
                      title: Text(
                        getTranslated(context, 'question_and_suggestion'),
                        style: const TextStyle(
                            fontSize: 14,
                            fontWeight: FontWeight.w600,
                            fontFamily: "Montserrat"),
                        textAlign: TextAlign.center,
                      ),
                      content: InkWell(
                        onTap: () {
                          launchUrlString("tel://+998712022202");
                        },
                        child: const Padding(
                          padding: EdgeInsets.all(8.0),
                          child: Text(
                            "+998 71 202 32 82",
                            textAlign: TextAlign.center,
                            style: TextStyle(
                                fontSize: 16,
                                color: Color(0xff6B95FF),
                                fontWeight: FontWeight.w600,
                                fontFamily: "Montserrat"),
                          ),
                        ),
                      ),
                    );
                  });
            },
            child: const Padding(
              padding: EdgeInsets.symmetric(horizontal: 16.0),
              child:
                  CircleAvatar(radius: 16, child: Icon(Icons.phone, size: 18)),
            ),
          )
        ],
        centerTitle: true,
        elevation: 0,
      ),
      body: BlocConsumer<SoliqIdBloc, SoliqIdState>(
        listener: (context, state) {
          if (state is SoliqIdAccountInfoSuccessState) {
            BlocProvider.of<SoliqIdBloc>(context).add(SoliqIdCreateSessionEvent(
              token: widget.guid,
              fio: state.response.data.fio,
              pinfl: int.parse(widget.pinfl),
              lang: "uz",
              projectId: 0,
            ));
          }
          if (state is SoliqIdCompareFaceSuccessState &&
              state.response.success == false) {
            Navigator.push(
              context,
              MaterialPageRoute(
                builder: (_) => MessageScreen(
                  success: false,
                  message: state.response.message,
                ),
              ),
            );
          }
          if (state is SoliqIdCompareFaceSuccessState &&
              state.response.success == true) {
            Navigator.push(
                context,
                MaterialPageRoute(
                    builder: (_) => MessageScreen(
                        success: true, message: state.response.message)));
          }
        },
        builder: (context, state) {
          log("$state");
          return Stack(
            children: [
              Align(
                alignment: Alignment.topCenter,
                child: Column(
                  children: [
                    const SizedBox(
                      height: 8,
                    ),
                    SizedBox(
                      width: MediaQuery.of(context).size.width / 2,
                      height: MediaQuery.of(context).size.width / 2,
                      child: Container(
                          margin: const EdgeInsets.all(18),
                          child: Image.asset("assets/icons/faa.png")
                             ),
                    ),
                    const SizedBox(
                      height: 24,
                    ),
                    BlocBuilder<SoliqIdBloc, SoliqIdState>(
                      builder: (context, state) {
                        if (state is SoliqIdAccountInfoSuccessState) {
                          return Text(
                            state.response.data.fio,
                            style: const TextStyle(
                              fontSize: 16,
                              fontWeight: FontWeight.w700,
                            ),
                          );
                        }
                        return const Text(
                          "",
                          style: TextStyle(
                            fontSize: 16,
                            fontWeight: FontWeight.w700,
                          ),
                        );
                      },
                    ),
                    const SizedBox(
                      height: 6,
                    ),
                    Text(
                      "${getString( 'pinfl')}: ${widget.pinfl}",
                      style: const TextStyle(
                        fontSize: 16,
                        fontWeight: FontWeight.w700,
                      ),
                    ),
                    const SizedBox(
                      height: 26,
                    ),
                    Container(
                      margin: const EdgeInsets.symmetric(horizontal: 28),
                      child: Text(getString( 'suggest_advice'),
                          textAlign: TextAlign.start,
                          style: FTypography.h1TextBold),
                    ),
                    const SizedBox(
                      height: 18,
                    ),
                    Padding(
                      padding: const EdgeInsets.symmetric(
                        horizontal: 24,
                      ),
                      child: Text(
                        getString( "advice"),
                        textAlign: TextAlign.start,
                        style: FTypography.h1Text1,
                      ),
                    ),
                    const SizedBox(
                      height: 18,
                    ),
                  ],
                ),
              ),
              Positioned(
                bottom: 0,
                left: 0,
                right: 0,
                child: Container(
                  margin: const EdgeInsets.only(bottom: 25),
                  child: Column(
                    children: [
                      BlocBuilder<SoliqIdBloc, SoliqIdState>(
                        // buildWhen: (p,c)=> c is SoliqIdCreateSessionSuccessState,
                        builder: (context, state) {
                          return AppButton(
                            title: buttonTitle,
                            isLoading: _isLoading,
                            isDisabled:
                                state is! SoliqIdCreateSessionSuccessState,
                            onTap: () async {
                              if (state is SoliqIdCreateSessionSuccessState) {
                                final response = await Navigator.push(
                                  context,
                                  MaterialPageRoute(
                                    builder: (_) => CameraScreen(
                                      session: state.response,
                                      token: widget.guid,
                                    ),
                                  ),
                                );
                                if (response != null) {
                                  BlocProvider.of<SoliqIdBloc>(context).add(
                                    SoliqIdCompareFaceEvent(
                                      token: widget.guid,
                                      deviceId: 'string',
                                      processId: state.response.sessionId,
                                      id: -60,
                                      asked: 7,
                                      date: response,
                                    ),
                                  );
                                }
                              }
                            },
                          );
                        },
                      ),
                    ],
                  ),
                ),
              ),
            ],
          );
        },
      ),
    );
  }
}
